@@ -1,4 +1,4 @@
-#!/21Q1/bin/python3.8
+#!/usr/pkg/bin/python3.12
 # coding=utf-8
 
 import threading
@@ -7,8 +7,10 @@ import webbrowser
 import inkex
 from inkex import Anchor
 
+
 class ThreadWebsite(threading.Thread):
     """Visit the website without locking inkscape"""
+
     def __init__(self, url):
         threading.Thread.__init__(self)
         self.url = url
@@ -16,13 +18,16 @@ class ThreadWebsite(threading.Thread):
     def run(self):
         webbrowser.open(self.url)
 
+
 class FollowLink(inkex.EffectExtension):
     """Get the first selected item and follow it's href/url"""
+
     def effect(self):
         for node in self.svg.selection.filter(Anchor):
-            vwswli = ThreadWebsite(node.get('xlink:href'))
+            vwswli = ThreadWebsite(node.get("xlink:href"))
             vwswli.start()
             break
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     FollowLink().run()
