@@ -1,4 +1,4 @@
-#!/21Q1/bin/python3.8
+#!/usr/pkg/bin/python3.12
 # coding=utf-8
 #
 # Copyright (C) 2011 Felipe Correa da Silva Sanches
@@ -20,12 +20,15 @@
 
 from next_glyph_layer import NextLayer
 
+
 class PreviousLayer(NextLayer):
     """Like next glyph layer, but for the previous"""
+
     @staticmethod
     def process_glyphs(glyphs, current):
         glyphs[current].set("style", "display:none")
-        glyphs[current-1].set("style", "display:inline")
+        glyphs[current - 1].set("style", "display:inline")
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     PreviousLayer().run()
