@@ -1,16 +1,18 @@
-#!/21Q1/bin/python3.8
+#!/usr/pkg/bin/python3.12
 """Convert to sentence case"""
 
 import inkex
 
+
 class SentenceCase(inkex.TextExtension):
     """Convert text to sentence case"""
+
     sentence_start = True
     was_punctuation = False
 
     def map_char(self, char):
         """Turn the char into a sentence using class state"""
-        if char in '.!?':
+        if char in ".!?":
             self.was_punctuation = True
         elif ((char.isspace() or self.newline) and self.was_punctuation) or self.newpar:
             self.sentence_start = True
@@ -31,5 +33,6 @@ class SentenceCase(inkex.TextExtension):
             return char.lower()
         return char
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     SentenceCase().run()
