@@ -1,10 +1,12 @@
-#!/21Q1/bin/python3.8
+#!/usr/pkg/bin/python3.12
 """Convert to title case"""
 
 import inkex
 
+
 class TitleCase(inkex.TextExtension):
     """To titlecase"""
+
     word_ended = True
 
     def process_chardata(self, text):
@@ -26,5 +28,6 @@ class TitleCase(inkex.TextExtension):
 
         return ret
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     TitleCase().run()
