@@ -1,12 +1,15 @@
-#!/21Q1/bin/python3.8
+#!/usr/pkg/bin/python3.12
 """Convert text to upper case"""
 
 import inkex
 
+
 class Uppercase(inkex.TextExtension):
     """To upper case"""
+
     def process_chardata(self, text):
         return text.upper()
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     Uppercase().run()
